@@ -1,9 +1,12 @@
 mod metrics;
+#[cfg(feature = "prometheus")]
+pub mod prometheus;
 mod registry;
 
 /// Export metrics types
 pub use crate::metrics::*;
 /// Re-export metrics crate
+#[doc(hidden)]
 pub use ::metrics::*;
 /// Re-export declarative macros
 pub use metrics_catalogue_macros::Catalogue;
